=== added file 'debian/mandos.postinst'
--- debian/mandos.postinst	1970-01-01 00:00:00 +0000
+++ debian/mandos.postinst	2008-09-19 00:54:24 +0000
@@ -0,0 +1,40 @@
+#!/bin/bash -e
+# This script can be called in the following ways:
+#
+# After the package was installed:
+#       <postinst> configure <old-version>
+#
+#
+# If prerm fails during upgrade or fails on failed upgrade:
+#       <old-postinst> abort-upgrade <new-version>
+#
+# If prerm fails during deconfiguration of a package:
+#       <postinst> abort-deconfigure in-favour <new-package> <version>
+#                  removing <old-package> <version>
+#
+# If prerm fails during replacement due to conflict:
+#       <postinst> abort-remove in-favour <new-package> <version>
+
+. /usr/share/debconf/confmodule
+
+case "$1" in
+    configure)
+	if ! getent passwd mandos >/dev/null; then
+	    adduser --disabled-password  --quiet --system \
+		--home /var/run/mandos --no-create-home \
+		--gecos "Mandos password daemon" --group mandos
+	fi
+	;;
+
+    abort-upgrade|abort-deconfigure|abort-remove)
+	;;
+
+    *)
+	echo "$0 called with unknown argument \`$1'" 1>&2
+	exit 1
+	;;
+esac
+
+#DEBHELPER#
+
+exit 0

=== added file 'debian/mandos.postrm'
--- debian/mandos.postrm	1970-01-01 00:00:00 +0000
+++ debian/mandos.postrm	2008-09-19 00:54:24 +0000
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+set -e
+
+#DEBHELPER#
+
+if [ "$1" = "purge" ] ; then
+        deluser --quiet --system mandos > /dev/null || true
+        delgroup --quiet --system mandos > /dev/null || true
+fi
+

=== modified file 'initramfs-tools-hook'
--- initramfs-tools-hook	2008-09-07 09:36:35 +0000
+++ initramfs-tools-hook	2008-09-19 00:54:24 +0000
@@ -120,6 +120,16 @@
     cp --archive --sparse=always "$file" "${DESTDIR}${CONFDIR}"
 done
 
+if [ ${mandos_user} != 65534 ]; then
+    PLUGINRUNNERCONF="${DESTDIR}${CONFDIR}/plugin-runner.conf"
+    echo "--userid=${mandos_user}" >> "$PLUGINRUNNERCONF"
+fi
+
+if [ ${mandos_group} != 65534 ]; then
+    PLUGINRUNNERCONF="${DESTDIR}${CONFDIR}/plugin-runner.conf"
+    echo "--groupid=${mandos_group}" >> "$PLUGINRUNNERCONF"
+fi
+
 # Key files 
 for file in  "$keydir"/*; do
     if [ -d "$file" ]; then

